package com.landray.kmss.sys.attachment.integrate.wps.provider;

import org.hibernate.Query;
import com.landray.kmss.sys.config.action.SysConfigAdminUtil;
import java.util.Properties;
import com.landray.kmss.sys.config.loader.ConfigLocationsUtil;
import com.landray.kmss.sys.attachment.integrate.wps.authen.WpsOfficeToken;
import com.landray.kmss.sys.authentication.util.StringUtil;
import com.landray.kmss.util.UserUtil;
import com.landray.kmss.sys.attachment.integrate.wps.authen.WpsOfficeTokenGenerator;
import com.landray.kmss.common.model.IBaseModel;
import com.landray.kmss.sys.attachment.integrate.wps.model.ThirdWpsOfficeToken;
import com.landray.kmss.sys.attachment.integrate.wps.cache.WpsOfficeTokenCache;
import com.landray.kmss.common.dao.HQLInfo;
import com.alibaba.fastjson.JSONObject;
import com.landray.kmss.sys.attachment.integrate.wps.model.ThirdWpsOfficeTokenInfo;
import com.landray.kmss.sys.authentication.token.LRTokenGenerator;
import com.landray.kmss.util.SpringBeanUtil;
import org.apache.commons.logging.LogFactory;
import com.landray.kmss.sys.attachment.integrate.wps.service.IThirdWpsOfficeTokenService;
import org.apache.commons.logging.Log;
import com.landray.kmss.sys.attachment.integrate.wps.interfaces.ISysAttachmentWpsAddinProvider;

public class SysAttachmentWpsAddinProviderImp implements ISysAttachmentWpsAddinProvider
{
    private static final Log logger;
    private static final String WPS_OFFICE_TOKEN_NAME = "WpsOfficeToken";
    private static final String WPS_OFFICE_TOKEN_FILE_NAME = "/LRToken";
    private static final String WPS_OFFICE_TOKEN_COOKIE_ADMIN = "cookie.domain";
    private static final String WPS_OFFICE_TOKEN_COOKIE_MAX_AGE = "43200";
    private static final String WPS_OFFICE_SECURITY_KEY_PUBLIC = "security.key.public";
    private static final String WPS_OFFICE_SECUTIRY_KEY_PRIVATE = "security.key.private";
    private IThirdWpsOfficeTokenService thirdWpsOfficeTokenService;
    
    static {
        logger = LogFactory.getLog(SysAttachmentWpsAddinProviderImp.class);
    }
    
    public SysAttachmentWpsAddinProviderImp() {
        this.thirdWpsOfficeTokenService = null;
    }
    
    private IThirdWpsOfficeTokenService getThirdWpsOfficeTokenService() {
        if (this.thirdWpsOfficeTokenService == null) {
            this.thirdWpsOfficeTokenService = (IThirdWpsOfficeTokenService)SpringBeanUtil.getBean("thirdWpsOfficeTokenokenService");
        }
        return this.thirdWpsOfficeTokenService;
    }
    
    public void addinAuthentication(final String url) {
        try {
            final LRTokenGenerator generator = new LRTokenGenerator();
            generator.generateKeys();
            final ThirdWpsOfficeTokenInfo thirdWpsOfficeTokenInfo = new ThirdWpsOfficeTokenInfo().setCookieDomain(url).setCookieMaxAge("43200").setCookieMaxAgeRedis("").setCookieName("WpsOfficeToken").setInstanceClass("WpsOfficeToken").setSecurityKeyPublic(generator.getPublicKey()).setSecurityKeyPrivate(generator.getPrivateKey());
            final String content = JSONObject.toJSONString((Object)thirdWpsOfficeTokenInfo);
            if (SysAttachmentWpsAddinProviderImp.logger.isDebugEnabled()) {
                SysAttachmentWpsAddinProviderImp.logger.debug("创建加载项使用的token信息：" + content);
            }
            final HQLInfo hqlInfo = new HQLInfo();
            final String whereBlock = "fdTokenName =:tokenName";
            hqlInfo.setWhereBlock(whereBlock);
            hqlInfo.setParameter("tokenName", (Object)"WpsOfficeToken");
            final Object obj = this.getThirdWpsOfficeTokenService().findFirstOne(hqlInfo);
            WpsOfficeTokenCache.getInstance().delete("WpsOfficeToken");
            if (obj == null) {
                final ThirdWpsOfficeToken thirdWpsOfficeToken = new ThirdWpsOfficeToken();
                thirdWpsOfficeToken.setFdTokenName("WpsOfficeToken");
                thirdWpsOfficeToken.setFdToken(content);
                this.getThirdWpsOfficeTokenService().add((IBaseModel)thirdWpsOfficeToken);
            }
            else {
                final ThirdWpsOfficeToken thirdWpsOfficeToken = (ThirdWpsOfficeToken)obj;
                thirdWpsOfficeToken.setFdToken(content);
                this.getThirdWpsOfficeTokenService().update((IBaseModel)thirdWpsOfficeToken);
            }
        }
        catch (final Exception e) {
            e.printStackTrace();
            SysAttachmentWpsAddinProviderImp.logger.error("wps加载项添加token出错:" + e);
        }
    }
    
    public String getToken() {
        try {
            WpsOfficeTokenGenerator.getInstance();
            WpsOfficeTokenGenerator.loadTokenInfo(this.getAuthentication());
            final WpsOfficeToken token = WpsOfficeTokenGenerator.getInstance().generateTokenByUserName(UserUtil.getUser().getFdLoginName());
            if (SysAttachmentWpsAddinProviderImp.logger.isDebugEnabled()) {
                SysAttachmentWpsAddinProviderImp.logger.debug("加载项项需要生成Token的信息,用户信息：" + UserUtil.getUser().getFdLoginName() + ",Token:" + token.getTokenString());
            }
            if (StringUtil.isNotNull(token.getTokenString())) {
                return token.getTokenString();
            }
        }
        catch (final Exception e) {
            e.printStackTrace();
        }
        SysAttachmentWpsAddinProviderImp.logger.error("加载项获取Token为空......");
        return "";
    }
    
    public String getAuthentication() {
        final String token = WpsOfficeTokenCache.getInstance().get("WpsOfficeToken");
        if (token != null && StringUtil.isNotNull(token)) {
            return token;
        }
        try {
            final HQLInfo hqlInfo = new HQLInfo();
            final String whereBlock = "fdTokenName =:tokenName";
            hqlInfo.setWhereBlock(whereBlock);
            hqlInfo.setParameter("tokenName", (Object)"WpsOfficeToken");
            final Object obj = this.getThirdWpsOfficeTokenService().findFirstOne(hqlInfo);
            if (obj != null) {
                final ThirdWpsOfficeToken thirdWpsOfficeToken = (ThirdWpsOfficeToken)obj;
                final String tokenContent = thirdWpsOfficeToken.getFdToken();
                WpsOfficeTokenCache.getInstance().set("WpsOfficeToken", tokenContent);
                return tokenContent;
            }
            String zdWebContentPath = ConfigLocationsUtil.getKmssConfigPath();
            if (StringUtil.isNull(zdWebContentPath)) {
                throw new IllegalAccessError("不存在LRToken,请在【附件机制】【WPS加载项配置】中开启加载项配置");
            }
            SysAttachmentWpsAddinProviderImp.logger.warn("表third_wps_office_token和缓存中不存在token,将从LRToken文件读取，若报错，请在【附件机制】【WPS加载项配置】中开启加载项配置");
            zdWebContentPath = String.valueOf(zdWebContentPath) + "/LRToken";
            final Properties prop = new Properties();
            SysConfigAdminUtil.loadProperties(prop, SysConfigAdminUtil.loadTokenKeyFileProperties(zdWebContentPath, SysConfigAdminUtil.isEncryptEnabled()), (String)null);
            final ThirdWpsOfficeTokenInfo thirdWpsOfficeTokenInfo = new ThirdWpsOfficeTokenInfo().setCookieDomain(prop.getProperty("cookie.domain")).setCookieMaxAge("43200").setCookieMaxAgeRedis("").setCookieName("WpsOfficeToken").setInstanceClass("WpsOfficeToken").setSecurityKeyPublic(prop.getProperty("security.key.public")).setSecurityKeyPrivate(prop.getProperty("security.key.private"));
            final String content = JSONObject.toJSONString((Object)thirdWpsOfficeTokenInfo);
            final ThirdWpsOfficeToken thirdWpsOfficeToken2 = new ThirdWpsOfficeToken();
            thirdWpsOfficeToken2.setFdTokenName("WpsOfficeToken");
            thirdWpsOfficeToken2.setFdToken(content);
            this.getThirdWpsOfficeTokenService().add((IBaseModel)thirdWpsOfficeToken2);
            WpsOfficeTokenCache.getInstance().set("WpsOfficeToken", content);
            return content;
        }
        catch (final Exception e) {
            e.printStackTrace();
            SysAttachmentWpsAddinProviderImp.logger.error("WPS加载项获取Token问题:缓存和数据库中都不存在token");
            return "";
        }
    }
    
    public void deleteToken() {
        try {
            WpsOfficeTokenCache.getInstance().delete("WpsOfficeToken");
            final String hql = "delete from ThirdWpsOfficeToken where fdTokenName =:tokenName";
            final Query query = (Query)this.getThirdWpsOfficeTokenService().getBaseDao().getHibernateSession().createQuery(hql);
            query.setParameter("tokenName", (Object)"WpsOfficeToken");
            query.executeUpdate();
        }
        catch (final Exception e) {
            e.printStackTrace();
            SysAttachmentWpsAddinProviderImp.logger.error("删除出错:" + e);
        }
    }
}
